==> vue-components-1.5.42.tgz: package/lib/theme/src/hooks/useTheme.rd.js <==
import { getCurrentInstance as p, reactive as m, onBeforeMount as $, watch as a, unref as l, nextTick as d, ref as g, computed as h } from "vue";
import { useInjectStyle as y } from "../../../shared/hooks/useInjectStyle.rd.js";
import v from "../../../node_modules/tailwindcss/colors.rd.js";
import { tailwindColorIntensity as I } from "../constants.rd.js";
function T(o = "primary", r = "violet", s) {
  const c = g(""), t = g(r), n = h(() => v[t.value]);
  a([t], u, { immediate: !0 }), y(c, o + " color-var", !1);
  function u() {
    c.value = "", I.forEach((e) => {
      const f = (s == null ? void 0 : s[e]) ?? n.value[e], b = C(f);
      document.documentElement.style.setProperty(`--${o}-color-${e}`, f), document.documentElement.style.setProperty(`--${o}-color-rgb-${e}`, b), c.value += E(e, o);
    });
  }
  return {
    setColor: (e) => t.value = e
  };
}
function P(o) {
  if (p()) {
    let r = function() {
      for (let t = 0; t < l(o).length; t++) {
        const { name: n, color: u, palette: i } = l(o)[t];
        if (n && (u || i)) {
          const { setColor: e } = T(n, u, i);
          c[n] = e;
        }
      }
    }, s = function() {
      d(() => {
        l(o).forEach(({ name: t, color: n }) => {
          t && n && c[t](n);
        });
      });
    };
    const c = m({});
    return $(r), a(o, s, { deep: !0 }), { updateThemes: s, setThemes: r };
  } else
    throw new Error("Use themes can only be used inside setup");
}
function C(o) {
  return parseInt(o.substring(1, 3), 16) + "," + parseInt(o.substring(3, 5), 16) + "," + parseInt(o.substring(5, 7), 16);
}
function E(o, r) {
  return `.bg-${r}-${o}, .dark .dark\\:hover\\:bg-${r}-${o}:hover, .hover\\:bg-${r}-${o}:hover {
	background-color: rgba(var(--${r}-color-rgb-${o}), var(--un-bg-opacity)) !important;
}
.text-${r}-${o} { 
	color: rgba(var(--${r}-color-rgb-${o}), var(--un-text-opacity)) !important
}`;
}
export {
  T as useTheme,
  P as useThemes
};

==> vue-components-1.6.6.tgz: package/lib/theme/src/hooks/useTheme.rd.js <==
import { getCurrentInstance as a, reactive as d, onBeforeMount as p, watch as b, unref as l, nextTick as m, ref as g, computed as h } from "vue";
import { useInjectStyle as y } from "../../../shared/hooks/useInjectStyle.rd.js";
import v from "../../../node_modules/tailwindcss/colors.rd.js";
import { tailwindColorIntensity as I } from "../constants.rd.js";
function T(o = "primary", r = "violet", s) {
  const c = g(""), t = g(r), n = h(() => v[t.value]);
  b([t], u, { immediate: !0 }), y(c, o + " color-var", !1);
  function u() {
    c.value = "", I.forEach((e) => {
      const f = (s == null ? void 0 : s[e]) ?? n.value[e], $ = C(f);
      document.documentElement.style.setProperty(`--${o}-color-${e}`, f), document.documentElement.style.setProperty(`--${o}-color-rgb-${e}`, $), c.value += E(e, o);
    });
  }
  return {
    setColor: (e) => t.value = e
  };
}
function P(o) {
  if (a()) {
    let r = function() {
      for (let t = 0; t < l(o).length; t++) {
        const { name: n, color: u, palette: i } = l(o)[t];
        if (n && (u || i)) {
          const { setColor: e } = T(n, u, i);
          c[n] = e;
        }
      }
    }, s = function() {
      m(() => {
        l(o).forEach(({ name: t, color: n }) => {
          t && n && c[t](n);
        });
      });
    };
    const c = d({});
    return p(r), b(o, s, { deep: !0 }), { updateThemes: s, setThemes: r };
  } else
    throw new Error("Use themes can only be used inside setup");
}
function C(o) {
  return parseInt(o.substring(1, 3), 16) + "," + parseInt(o.substring(3, 5), 16) + "," + parseInt(o.substring(5, 7), 16);
}
function E(o, r) {
  return `.bg-${r}-${o}, .dark .dark\\:hover\\:bg-${r}-${o}:hover, .hover\\:bg-${r}-${o}:hover {
	background-color: rgba(var(--${r}-color-rgb-${o}), var(--un-bg-opacity));
}
.text-${r}-${o} { 
	color: rgba(var(--${r}-color-rgb-${o}), var(--un-text-opacity));
}`;
}
export {
  T as useTheme,
  P as useThemes
};
